==> haskell-binary-conduit-1.3.1-488-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-1yEdIHZPqfWsVhOOzs02o
key:                  binary-conduit-1.3.1-1yEdIHZPqfWsVhOOzs02o
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  bd395547a9aaca09bdcf43592d5b9045
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-1yEdIHZPqfWsVhOOzs02o
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-HwOUBFINqL9Hdg9Zavx6kP exceptions-0.10.5
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3.1-490-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-conduit
version:              1.3.1
visibility:           public
id:                   binary-conduit-1.3.1-20br63bTQDiJsL9uBG16lP
key:                  binary-conduit-1.3.1-20br63bTQDiJsL9uBG16lP
license:              MIT
copyright:            2013 Alexander Vershilov
maintainer:           alexander.vershilov@gmail.com
author:               Alexander Vershilov
stability:            Experimental
homepage:             http://github.com/qnikst/binary-conduit/
synopsis:             data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.

category:             Conduit
abi:                  8cc086892cc8608179c10b95229b9012
exposed:              True
exposed-modules:      Data.Conduit.Serialization.Binary
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-conduit
hs-libraries:         HSbinary-conduit-1.3.1-20br63bTQDiJsL9uBG16lP
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    conduit-1.3.6.1-8tCAQIrauyrIug3BXDjEe3 exceptions-0.10.5
    vector-0.13.1.0-4yrO9MMzvlSAj3sbKvUmkp

haddock-interfaces:
    /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock

haddock-html:         /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
